from .tag import Tag
from .gen_elements import typed_partial

a = typed_partial(Tag, 'a')
abbr = typed_partial(Tag, 'abbr')
acronym = typed_partial(Tag, 'acronym')
address = typed_partial(Tag, 'address')
animate = typed_partial(Tag, 'animate')
animateMotion = typed_partial(Tag, 'animateMotion')
animateTransform = typed_partial(Tag, 'animateTransform')
applet = typed_partial(Tag, 'applet')
area = typed_partial(Tag, 'area')
article = typed_partial(Tag, 'article')
aside = typed_partial(Tag, 'aside')
audio = typed_partial(Tag, 'audio')
b = typed_partial(Tag, 'b')
base = typed_partial(Tag, 'base')
basefont = typed_partial(Tag, 'basefont')
bdi = typed_partial(Tag, 'bdi')
bdo = typed_partial(Tag, 'bdo')
big = typed_partial(Tag, 'big')
blockquote = typed_partial(Tag, 'blockquote')
body = typed_partial(Tag, 'body')
br = typed_partial(Tag, 'br')
button = typed_partial(Tag, 'button')
canvas = typed_partial(Tag, 'canvas')
caption = typed_partial(Tag, 'caption')
center = typed_partial(Tag, 'center')
circle = typed_partial(Tag, 'circle')
cite = typed_partial(Tag, 'cite')
clipPath = typed_partial(Tag, 'clipPath')
code = typed_partial(Tag, 'code')
col = typed_partial(Tag, 'col')
colgroup = typed_partial(Tag, 'colgroup')
data = typed_partial(Tag, 'data')
datalist = typed_partial(Tag, 'datalist')
dd = typed_partial(Tag, 'dd')
defs = typed_partial(Tag, 'defs')
del_ = typed_partial(Tag, 'del')
desc = typed_partial(Tag, 'desc')
details = typed_partial(Tag, 'details')
dfn = typed_partial(Tag, 'dfn')
dialog = typed_partial(Tag, 'dialog')
dir = typed_partial(Tag, 'dir')
div = typed_partial(Tag, 'div')
dl = typed_partial(Tag, 'dl')
dt = typed_partial(Tag, 'dt')
ellipse = typed_partial(Tag, 'ellipse')
em = typed_partial(Tag, 'em')
embed = typed_partial(Tag, 'embed')
feBlend = typed_partial(Tag, 'feBlend')
feColorMatrix = typed_partial(Tag, 'feColorMatrix')
feComponentTransfer = typed_partial(Tag, 'feComponentTransfer')
feComposite = typed_partial(Tag, 'feComposite')
feConvolveMatrix = typed_partial(Tag, 'feConvolveMatrix')
feDiffuseLighting = typed_partial(Tag, 'feDiffuseLighting')
feDisplacementMap = typed_partial(Tag, 'feDisplacementMap')
feDistantLight = typed_partial(Tag, 'feDistantLight')
feDropShadow = typed_partial(Tag, 'feDropShadow')
feFlood = typed_partial(Tag, 'feFlood')
feFuncA = typed_partial(Tag, 'feFuncA')
feFuncB = typed_partial(Tag, 'feFuncB')
feFuncG = typed_partial(Tag, 'feFuncG')
feFuncR = typed_partial(Tag, 'feFuncR')
feGaussianBlur = typed_partial(Tag, 'feGaussianBlur')
feImage = typed_partial(Tag, 'feImage')
feMerge = typed_partial(Tag, 'feMerge')
feMergeNode = typed_partial(Tag, 'feMergeNode')
feMorphology = typed_partial(Tag, 'feMorphology')
feOffset = typed_partial(Tag, 'feOffset')
fePointLight = typed_partial(Tag, 'fePointLight')
feSpecularLighting = typed_partial(Tag, 'feSpecularLighting')
feSpotLight = typed_partial(Tag, 'feSpotLight')
feTile = typed_partial(Tag, 'feTile')
feTurbulence = typed_partial(Tag, 'feTurbulence')
fieldset = typed_partial(Tag, 'fieldset')
figcaption = typed_partial(Tag, 'figcaption')
figure = typed_partial(Tag, 'figure')
filter = typed_partial(Tag, 'filter')
font = typed_partial(Tag, 'font')
footer = typed_partial(Tag, 'footer')
foreignObject = typed_partial(Tag, 'foreignObject')
form = typed_partial(Tag, 'form')
frame = typed_partial(Tag, 'frame')
frameset = typed_partial(Tag, 'frameset')
g = typed_partial(Tag, 'g')
h1 = typed_partial(Tag, 'h1')
h2 = typed_partial(Tag, 'h2')
h3 = typed_partial(Tag, 'h3')
h4 = typed_partial(Tag, 'h4')
h5 = typed_partial(Tag, 'h5')
h6 = typed_partial(Tag, 'h6')
head = typed_partial(Tag, 'head')
header = typed_partial(Tag, 'header')
hgroup = typed_partial(Tag, 'hgroup')
hr = typed_partial(Tag, 'hr')
html = typed_partial(Tag, 'html')
i = typed_partial(Tag, 'i')
iframe = typed_partial(Tag, 'iframe')
image = typed_partial(Tag, 'image')
img = typed_partial(Tag, 'img')
input_ = typed_partial(Tag, 'input')
ins = typed_partial(Tag, 'ins')
kbd = typed_partial(Tag, 'kbd')
label = typed_partial(Tag, 'label')
legend = typed_partial(Tag, 'legend')
li = typed_partial(Tag, 'li')
line = typed_partial(Tag, 'line')
linearGradient = typed_partial(Tag, 'linearGradient')
link = typed_partial(Tag, 'link')
main = typed_partial(Tag, 'main')
map_ = typed_partial(Tag, 'map')
mark = typed_partial(Tag, 'mark')
marker = typed_partial(Tag, 'marker')
mask = typed_partial(Tag, 'mask')
menu = typed_partial(Tag, 'menu')
meta = typed_partial(Tag, 'meta')
metadata = typed_partial(Tag, 'metadata')
meter = typed_partial(Tag, 'meter')
mpath = typed_partial(Tag, 'mpath')
nav = typed_partial(Tag, 'nav')
noframes = typed_partial(Tag, 'noframes')
noscript = typed_partial(Tag, 'noscript')
object_ = typed_partial(Tag, 'object')
ol = typed_partial(Tag, 'ol')
optgroup = typed_partial(Tag, 'optgroup')
option = typed_partial(Tag, 'option')
output = typed_partial(Tag, 'output')
p = typed_partial(Tag, 'p')
param = typed_partial(Tag, 'param')
path = typed_partial(Tag, 'path')
pattern = typed_partial(Tag, 'pattern')
picture = typed_partial(Tag, 'picture')
polygon = typed_partial(Tag, 'polygon')
polyline = typed_partial(Tag, 'polyline')
pre = typed_partial(Tag, 'pre')
progress = typed_partial(Tag, 'progress')
q = typed_partial(Tag, 'q')
radialGradient = typed_partial(Tag, 'radialGradient')
rect = typed_partial(Tag, 'rect')
rp = typed_partial(Tag, 'rp')
rt = typed_partial(Tag, 'rt')
ruby = typed_partial(Tag, 'ruby')
s = typed_partial(Tag, 's')
samp = typed_partial(Tag, 'samp')
script = typed_partial(Tag, 'script')
search = typed_partial(Tag, 'search')
section = typed_partial(Tag, 'section')
select = typed_partial(Tag, 'select')
set = typed_partial(Tag, 'set')
small = typed_partial(Tag, 'small')
source = typed_partial(Tag, 'source')
span = typed_partial(Tag, 'span')
stop = typed_partial(Tag, 'stop')
strike = typed_partial(Tag, 'strike')
strong = typed_partial(Tag, 'strong')
style = typed_partial(Tag, 'style')
sub = typed_partial(Tag, 'sub')
summary = typed_partial(Tag, 'summary')
sup = typed_partial(Tag, 'sup')
svg = typed_partial(Tag, 'svg')
switch = typed_partial(Tag, 'switch')
symbol = typed_partial(Tag, 'symbol')
table = typed_partial(Tag, 'table')
tbody = typed_partial(Tag, 'tbody')
td = typed_partial(Tag, 'td')
template = typed_partial(Tag, 'template')
text = typed_partial(Tag, 'text')
textPath = typed_partial(Tag, 'textPath')
textarea = typed_partial(Tag, 'textarea')
tfoot = typed_partial(Tag, 'tfoot')
th = typed_partial(Tag, 'th')
thead = typed_partial(Tag, 'thead')
time = typed_partial(Tag, 'time')
title = typed_partial(Tag, 'title')
tr = typed_partial(Tag, 'tr')
track = typed_partial(Tag, 'track')
tspan = typed_partial(Tag, 'tspan')
tt = typed_partial(Tag, 'tt')
u = typed_partial(Tag, 'u')
ul = typed_partial(Tag, 'ul')
use = typed_partial(Tag, 'use')
var = typed_partial(Tag, 'var')
video = typed_partial(Tag, 'video')
view = typed_partial(Tag, 'view')
wbra = typed_partial(Tag, 'wbra')
